@@ -256,7 +256,6 @@ xmlSecIORegisterCallbacks(xmlInputMatchCallback matchFunc,
     return(0);
 }
 
-
 /** File IO **/
 static int
 xmlSecIOFileExtractFilename(char const* filename, char** out) {
@@ -267,19 +266,15 @@ xmlSecIOFileExtractFilename(char const* filename, char** out) {
 
     if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file://localhost/", 17)) {
         escaped = &filename[16];
-    }
-    else if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file:///", 8)) {
+    } else if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file:///", 8)) {
         escaped = &filename[7];
-    }
-    else if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file://", 7)) {
+    } else if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file://", 7)) {
         /* lots of generators seems to lazy to read RFC 1738 */
         escaped = &filename[6];
-    }
-    else if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file:/", 6)) {
+    } else if (!xmlStrncasecmp(BAD_CAST filename, BAD_CAST "file:/", 6)) {
         /* lots of generators seems to lazy to read RFC 1738 */
         escaped = &filename[5];
-    }
-    else {
+    } else {
         (*out) = NULL;
         return(0); /* hope for the best */
     }
@@ -373,17 +368,15 @@ xmlSecIOFileOpen(char const* filename) {
 static int
 xmlSecIOFileRead(void* context, char* buffer, int len) {
     FILE* fd = (FILE*)context;
-    xmlSecSize szLen, szBytes;
-    size_t bytes;
+    size_t szLen, szBytes;
     int res;
 
     xmlSecAssert2(fd != NULL, -1);
     xmlSecAssert2(buffer != NULL, -1);
 
     XMLSEC_SAFE_CAST_INT_TO_SIZE(len, szLen, return(-1), NULL);
-    bytes = fread(buffer, 1, szLen, fd);
-    XMLSEC_SAFE_CAST_SIZE_T_TO_SIZE(bytes, szBytes, return(-1), NULL);
 
+    szBytes = fread(buffer, 1, szLen, fd);
     if ((szBytes < szLen) && (ferror(fd))) {
         xmlSecInternalError("fread", NULL);
         return(-1);
