@@ -27,6 +27,7 @@
 #include <xmlsec/keyinfo.h>
 #include <xmlsec/keysmngr.h>
 #include <xmlsec/xmltree.h>
+#include <xmlsec/private.h>
 
 #include <xmlsec/mscng/crypto.h>
 #include <xmlsec/mscng/x509.h>
@@ -455,32 +456,33 @@ xmlSecMSCngX509StoreContainsCert(HCERTSTORE store, CERT_NAME_BLOB* name,
     xmlSecAssert2(name != NULL, -1);
     xmlSecAssert2(cert != NULL, -1);
 
-    storeCert = CertFindCertificateInStore(store,
-        X509_ASN_ENCODING | PKCS_7_ASN_ENCODING,
-        0,
-        CERT_FIND_SUBJECT_NAME,
-        name,
-        NULL);
-    if (storeCert == NULL) {
-        return (0);
+    while (TRUE) {
+        storeCert = CertFindCertificateInStore(store,
+            X509_ASN_ENCODING | PKCS_7_ASN_ENCODING,
+            0,
+            CERT_FIND_SUBJECT_NAME,
+            name,
+            storeCert);
+        if (storeCert == NULL) {
+            return (0);
+        }
+
+        ret = xmlSecMSCngX509StoreVerifySubject(cert, storeCert);
+        if (ret < 0) {
+            xmlSecInternalError("xmlSecMSCngX509StoreVerifySubject", NULL);
+            continue; /* storeCert will be released in the next CertFindCertificateInStore() call */
+        } else if (ret == 0) {
+            xmlSecOtherError(XMLSEC_ERRORS_R_CERT_VERIFY_FAILED, NULL, "xmlSecMSCngX509StoreVerifySubject");
+            continue; /* storeCert will be released in the next CertFindCertificateInStore() call */
+        }
+
+        /* success */
+        CertFreeCertificateContext(storeCert);
+        return(1);
     }
 
-    ret = xmlSecMSCngX509StoreVerifySubject(cert, storeCert);
-    if (ret < 0) {
-        xmlSecInternalError("xmlSecMSCngX509StoreVerifySubject", NULL);
-        CertFreeCertificateContext(storeCert);
-        return(-1);
-    } else if (ret == 0) {
-        xmlSecOtherError(XMLSEC_ERRORS_R_CERT_VERIFY_FAILED,
-            NULL,
-            "xmlSecMSCngX509StoreVerifySubject");
-        CertFreeCertificateContext(storeCert);
-        return(-1);
-    }
-
-    /* success */
-    CertFreeCertificateContext(storeCert);
-    return(1);
+    /* no luck */
+    return (0);
 }
 
 static int
@@ -509,7 +511,7 @@ xmlSecMSCngVerifyCertTime(PCCERT_CONTEXT cert, LPFILETIME time) {
 /**
  * xmlSecMSCngX509StoreVerifyCertificateOwn:
  * @cert: the certificate to verify.
- * @time: pointer to FILETIME that we are interested in
+ * @time: pointer to FILETIME that we are interested in (if NULL, don't check certificate notBefore/notAfter)
  * @trustedStore: trusted certificates added via xmlSecMSCngX509StoreAdoptCert().
  * @certStore: the untrusted certificates stack.
  * @store: key data store, name used for error reporting only.
@@ -529,13 +531,16 @@ xmlSecMSCngX509StoreVerifyCertificateOwn(PCCERT_CONTEXT cert, FILETIME* time,
     xmlSecAssert2(trustedStore != NULL, -1);
     xmlSecAssert2(certStore != NULL, -1);
 
-    /* check certificate validity and revokation */
-    ret = xmlSecMSCngVerifyCertTime(cert, time);
-    if(ret < 0) {
-        xmlSecInternalError("xmlSecMSCngVerifyCertTime", NULL);
-        return(-1);
+    /* if time is specified, check certificate notBefore/notAfter */
+    if (time != NULL) {
+        ret = xmlSecMSCngVerifyCertTime(cert, time);
+        if (ret < 0) {
+            xmlSecInternalError("xmlSecMSCngVerifyCertTime", NULL);
+            return(-1);
+        }
     }
 
+    /* check certificate revokation */
     ret = xmlSecMSCngCheckRevocation(certStore, cert);
     if(ret < 0) {
         xmlSecInternalError("xmlSecMSCngCheckRevocation", NULL);
@@ -767,7 +772,8 @@ static int
 xmlSecMSCngX509StoreVerifyCertificate(xmlSecMSCngX509StoreCtxPtr ctx, PCCERT_CONTEXT cert,
     HCERTSTORE certStore, xmlSecKeyInfoCtx* keyInfoCtx
 ) {
-    FILETIME fTime;
+    FILETIME timeContainer;
+    FILETIME* time = &timeContainer;
     int ret;
 
     xmlSecAssert2(ctx != NULL, -1);
@@ -783,15 +789,18 @@ xmlSecMSCngX509StoreVerifyCertificate(xmlSecMSCngX509StoreCtxPtr ctx, PCCERT_CON
         return(1);
     }
 
+    /* do we need to check certificate notBefore/notAfter times? */
     if(keyInfoCtx->certsVerificationTime > 0) {
-        xmlSecMSCngUnixTimeToFileTime(keyInfoCtx->certsVerificationTime, &fTime);
+        xmlSecMSCngUnixTimeToFileTime(keyInfoCtx->certsVerificationTime, time);
+    } else if ((keyInfoCtx->flags & XMLSEC_KEYINFO_FLAGS_X509DATA_SKIP_TIME_CHECKS) != 0) {
+        time = NULL;
     } else {
         /* current time */
-        GetSystemTimeAsFileTime(&fTime);
+        GetSystemTimeAsFileTime(time);
     }
 
     /* verify based on the own trusted certificates */
-    ret = xmlSecMSCngX509StoreVerifyCertificateOwn(cert, &fTime,
+    ret = xmlSecMSCngX509StoreVerifyCertificateOwn(cert, time,
         ctx->trusted, ctx->untrusted, certStore);
     if(ret < 0){
         xmlSecInternalError("xmlSecMSCngX509StoreVerifyCertificateOwn", NULL);
@@ -802,8 +811,7 @@ xmlSecMSCngX509StoreVerifyCertificate(xmlSecMSCngX509StoreCtxPtr ctx, PCCERT_CON
     }
 
     /* verify based on the system certificates */
-    ret = xmlSecMSCngX509StoreVerifyCertificateSystem(cert, &fTime,
-        ctx->untrusted, certStore);
+    ret = xmlSecMSCngX509StoreVerifyCertificateSystem(cert, time, ctx->untrusted, certStore);
     if (ret < 0) {
         xmlSecInternalError("xmlSecMSCngX509StoreVerifyCertificateSystem", NULL);
         return(-1);
