@@ -6,7 +6,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  * Copyright (c) 2003 America Online, Inc.  All rights reserved.
  */
 /**
@@ -26,7 +26,7 @@
 #include <cert.h>
 #include <certdb.h>
 #include <keyhi.h>
-#include <pk11func.h>
+#include <pk11pub.h>
 #include <pkcs12.h>
 #include <p12plcy.h>
 /*
