@@ -4,7 +4,7 @@
 #
 
 # ensure this script is called from testrun.sh
-if [ -z "$xmlsec_app" -o -z "$crypto_config_folder" ]; then
+if [ -z "$xmlsec_app" -o -z "$xmlsec_params" ]; then
     echo "This script needs to be called from testrun.sh script"
     exit 1
 fi
@@ -516,7 +516,31 @@ if [ "z$crypto" = "zopenssl" -o "z$crypto" = "znss" -o "z$crypto" = "zgnutls" ]
         "--untrusted-$cert_format $topfolder/keys/largersacert.$cert_format --untrusted-$cert_format $topfolder/keys/ca2cert.$cert_format --trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509" \
         "$priv_key_option $topfolder/keys/largersakey$priv_key_suffix.$priv_key_format --pwd secret123" \
         "--untrusted-$cert_format $topfolder/keys/largersacert.$cert_format --untrusted-$cert_format $topfolder/keys/ca2cert.$cert_format --trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509"
+fi
 
+# Only NSS can lookup certs in NSS DB, skip certs verification for signatures
+if [ "z$crypto" = "znss"  ] ; then
+    extra_message="Signature cert lookup in NSS DB"
+    execDSigTestWithCryptoConfig $res_success \
+        "" \
+        "aleksey-xmldsig-01/enveloped-x509-subjectname" \
+        "sha512 rsa-sha512" \
+        "rsa x509" \
+        "--untrusted-$cert_format $topfolder/keys/largersacert.$cert_format --untrusted-$cert_format $topfolder/keys/ca2cert.$cert_format --trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509" \
+        "--insecure" \
+        "--untrusted-$cert_format $topfolder/keys/largersacert.$cert_format --untrusted-$cert_format $topfolder/keys/ca2cert.$cert_format --trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509" \
+        "$topfolder/keys/nssdb"
+
+    extra_message="Signature cert lookup in NSS DB"
+    execDSigTestWithCryptoConfig $res_success \
+        "" \
+        "aleksey-xmldsig-01/enveloped-x509-issuerserial" \
+        "sha512 rsa-sha512" \
+        "rsa x509" \
+        "--untrusted-$cert_format $topfolder/keys/largersacert.$cert_format --untrusted-$cert_format $topfolder/keys/ca2cert.$cert_format --trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509" \
+        "--insecure" \
+        "--untrusted-$cert_format $topfolder/keys/largersacert.$cert_format --untrusted-$cert_format $topfolder/keys/ca2cert.$cert_format --trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509" \
+        "$topfolder/keys/nssdb"
 fi
 
 # MSCng only supports SHA1 as cert digests and cannot lookup the key
@@ -1099,25 +1123,6 @@ execDSigTest $res_success \
     "ec x509" \
     "--trusted-$cert_format $topfolder/keys/enveloped-ecdsa-java-bug-cert.$cert_format --enabled-key-data x509 --verification-gmt-time 2019-01-01+00:00:00"
 
-
-extra_message="DTD is present"
-execDSigTest $res_success \
-    "" \
-    "aleksey-xmldsig-01/dtd-hmac-91" \
-    "sha1 hmac-sha1" \
-    "hmac" \
-    "--hmackey:name:KEY $topfolder/keys/hmackey.bin --dtd-file $topfolder/aleksey-xmldsig-01/dtd-hmac-91.dtd" \
-    "--hmackey:mykey $topfolder/keys/hmackey.bin --dtd-file $topfolder/aleksey-xmldsig-01/dtd-hmac-91.dtd" \
-    "--hmackey:mykey $topfolder/keys/hmackey.bin --dtd-file $topfolder/aleksey-xmldsig-01/dtd-hmac-91.dtd"
-
-extra_message="Negative test: missing DTD"
-execDSigTest $res_fail \
-    "" \
-    "aleksey-xmldsig-01/dtd-hmac-91" \
-    "sha1 hmac-sha1" \
-    "hmac" \
-    "--enabled-reference-uris empty --hmackey $topfolder/keys/hmackey.bin --dtd-file $topfolder/aleksey-xmldsig-01/dtd-hmac-91.dtd"
-
 execDSigTest $res_success \
     "" \
     "aleksey-xmldsig-01/x509data-test" \
@@ -1152,8 +1157,8 @@ extra_message="Negative test: expired cert"
 execDSigTest $res_fail \
     "" \
     "aleksey-xmldsig-01/enveloping-expired-cert" \
-    "sha1 dsa-sha1" \
-    "dsa x509" \
+    "sha1 rsa-sha1" \
+    "rsa x509" \
     "--trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509 --verification-gmt-time 2022-12-20+00:00:00"
 
 # Expired cert but there is verification time overwrite
@@ -1165,13 +1170,26 @@ execDSigTest $res_success \
     "rsa x509" \
     "--trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509 --verification-gmt-time 2022-12-14+00:00:00"
 
+
+# currently only openssl and gnutls support skipping time checks
+# https://github.com/lsh123/xmlsec/issues/852
+if [ "z$crypto" = "zopenssl" -o "z$crypto" = "zgnutls" -o "z$crypto" = "zmscng"  ] ; then
+    extra_message="Expired cert but we skip timestamp checks"
+    execDSigTest $res_success \
+        "" \
+        "aleksey-xmldsig-01/enveloping-expired-cert" \
+        "sha1 rsa-sha1" \
+        "rsa x509" \
+        "--trusted-$cert_format $topfolder/keys/cacert.$cert_format --enabled-key-data x509 --X509-skip-time-checks"
+fi
+
 # 'Verify existing signature' MUST fail here, as --trusted-... is not passed.
 # If this passes, that's a bug. Note that we need to cleanup NSS certs DB
 # since it automaticall stores trusted certs
-extra_message="Missing trusted cert but there is --insecure bypass"
+extra_message="Missing trusted cert "
 execDSigTest $res_fail \
     "aleksey-xmldsig-01" \
-    "enveloping-sha256-rsa-sha256-verify" \
+    "enveloping-sha256-rsa-sha256" \
     "sha256 rsa-sha256" \
     "rsa x509" \
     "--enabled-key-data x509"
@@ -1179,20 +1197,62 @@ execDSigTest $res_fail \
 # This is the same, but due to --insecure it must pass.
 # If this fails, that means avoiding the certificate verification doesn't
 # happen correctly
-extra_message="Negative test: missing trusted cert"
+extra_message="Negative test: missing trusted cert but there is --insecure bypass"
 execDSigTest $res_success \
     "aleksey-xmldsig-01" \
-    "enveloping-sha256-rsa-sha256-verify" \
+    "enveloping-sha256-rsa-sha256" \
     "sha256 rsa-sha256" \
     "rsa x509" \
     "--enabled-key-data x509 --insecure"
 
+
+
+# Test was created using the following command:
+# xmlsec.exe sign --crypto openssl  --lax-key-search --privkey-pem tests/keys/same-subj-key1.pem,tests/keys/same-subj-cert1.pem tests/aleksey-xmldsig-01/enveloped-x509-same-subj-cert.tmpl
+
+# this should succeeed with good cert
+extra_message="Cert chain is good"
+execDSigTest $res_success \
+    "" \
+    "aleksey-xmldsig-01/enveloped-x509-same-subj-cert" \
+    "sha256 rsa-sha256" \
+    "x509" \
+    "--trusted-$cert_format $topfolder/keys/same-subj-cert1.$cert_format --enabled-key-data x509"
+
+# this should fail: Same subject but wrong cert
+extra_message="Negative test: Same subject but wrong cert"
+execDSigTest $res_fail \
+    "" \
+    "aleksey-xmldsig-01/enveloped-x509-same-subj-cert" \
+    "sha256 rsa-sha256" \
+    "x509" \
+    "--trusted-$cert_format $topfolder/keys/same-subj-cert2.$cert_format --enabled-key-data x509"
+
+# this should succeeed with both good (cert1) and bad (cert2) certs present (simulating key rotation)
+extra_message="Cert chain is good: both good (cert1) and bad (cert2) certs present"
+execDSigTest $res_success \
+    "" \
+    "aleksey-xmldsig-01/enveloped-x509-same-subj-cert" \
+    "sha256 rsa-sha256" \
+    "x509" \
+    "--trusted-$cert_format $topfolder/keys/same-subj-cert1.$cert_format --trusted-$cert_format $topfolder/keys/same-subj-cert2.$cert_format --enabled-key-data x509"
+
+# this should succeeed with both bad (cert2) and good (cert1) certs present (simulating key rotation)
+extra_message="Cert chain is good: both bad (cert2) and good (cert1) certs present"
+execDSigTest $res_success \
+    "" \
+    "aleksey-xmldsig-01/enveloped-x509-same-subj-cert" \
+    "sha256 rsa-sha256" \
+    "x509" \
+    "--trusted-$cert_format $topfolder/keys/same-subj-cert2.$cert_format --trusted-$cert_format $topfolder/keys/same-subj-cert1.$cert_format --enabled-key-data x509"
+
+
 # Test was created using the following command:
 # xmlsec1 sign --lax-key-search --privkey-pem tests/keys/rsakey.pem,tests/keys/rsacert.pem tests/aleksey-xmldsig-01/enveloped-x509-missing-cert.tmpl
 #
 
 # this should succeeed with both intermidiate and trusted certs provided
-extra_message="Cert chaing is good"
+extra_message="Cert chain is good: both intermidiate and trusted certs provided"
 execDSigTest $res_success \
     "" \
     "aleksey-xmldsig-01/enveloped-x509-missing-cert" \
@@ -1785,12 +1845,12 @@ execDSigTest $res_fail \
 if [ -n "$XMLSEC_TEST_NAME" -a "$XMLSEC_TEST_NAME" = "dsig-dynamic" ]; then
 echo "Dynamic signature template"
 printf "    Create new signature                                 "
-echo "$VALGRIND $xmlsec_app sign-tmpl $xmlsec_params --keys-file $keysfile --output $tmpfile" >> $logfile
-$VALGRIND $xmlsec_app sign-tmpl $xmlsec_params --keys-file $keysfile --output $tmpfile >> $logfile 2>> $logfile
+echo "$VALGRIND $xmlsec_app sign-tmpl $xmlsec_params --crypto-config $default_crypto_config --keys-file $topfolder/keys/keys.xml --output $tmpfile" >> $logfile
+$VALGRIND $xmlsec_app sign-tmpl $xmlsec_params --crypto-config $default_crypto_config --keys-file $topfolder/keys/keys.xml --output $tmpfile >> $logfile 2>> $logfile
 printRes $res_success $?
 printf "    Verify new signature                                 "
-echo "$VALGRIND $xmlsec_app verify --keys-file $keysfile $tmpfile" >> $logfile
-$VALGRIND $xmlsec_app verify $xmlsec_params --keys-file $keysfile $tmpfile >> $logfile 2>> $logfile
+echo "$VALGRIND $xmlsec_app verify --keys-file $topfolder/keys/keys.xml $tmpfile" >> $logfile
+$VALGRIND $xmlsec_app verify $xmlsec_params --crypto-config $default_crypto_config --keys-file $topfolder/keys/keys.xml $tmpfile >> $logfile 2>> $logfile
 printRes $res_success $?
 fi
 
